Changelog
=========


1.0a3 (2024-02-20)
------------------

- Add an optional link to statistics browserview in user menu
  [remdub]


1.0a2 (2024-02-16)
------------------

- Rename package to collective.plausible
  [remdub]


1.0a1 (2024-02-15)
------------------

- Initial release.
  [remdub]
